Structs
- Input
Message - Message used to send client inputs to the server.
Stores the last N inputs starting from
end_tick - N + 1. - PerTarget
Data - Contains the input data for a specific target entity over a range of ticks.
Enums
- Input
Target - Enum indicating the target entity for the input.
Traits
- Action
State Sequence - An ActionStateSequence represents a sequence of states that can be serialized and sent over the network.